{% load url from future %}
{% load i18n %}
{% if content_object %}
    <form method="post" action="{% url "feedback_form" %}">
        {% csrf_token %}
        <p>{% trans "You are about to report:" %} {{ content_object }}</p>
        {{ form.as_p }}
        <input type="submit" value="{% trans "Send Feedback" %}" />
    </form>
{% else %}
    <a id="feedbackSnippet" href="{% url "feedback_form" %}" style="background-color: {{ background_color }};"></a>
    <p id="feedbackSuccess">{% trans "Thank you!" %}</p>
    <form id="feedbackForm" method="post" action="{% url "feedback_form" %}" style="background-color: {{ background_color }};">
        {% include "feedback_form/partials/form_content.html" %}
    </form>
{% endif %}