{% load i18n libs_tags %}
<h2>
    {% if feedback.content_object %}
        {% trans "A new report has been posted:" %}
    {% else %}
        {% trans "A new feedback has been posted:" %}
    {% endif %}
</h2>

<p>{% trans "URL" %}: {{ url }}</p>
{% if feedback.content_object %}
    <p>{% trans "Object type" %}: {{ feedback.content_object|get_content_type:'model' }}</p>
    <p>{% trans "Object PK" %}: {{ feedback.content_object.pk }}</p>
{% endif %}
{% if feedback.email %}
    <p>{% trans "Email" %}: {{ feedback.email }}</p>
{% else %}
    <p>{% trans "Email" %}: {{ feedback.user.email }}</p>
{% endif %}
<p>{% trans "Date" %}: {{ feedback.creation_date|date }}</p>
<hr />
<p>{{ feedback.message }}</p>
